# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`fail2ban`](#fail2ban): Installs, configures and manages the Fail2ban service.
* [`fail2ban::install`](#fail2ban--install): == Class: fail2ban::install

#### Private Classes

* `fail2ban::config`: Handles the configuration file.
* `fail2ban::service`: Handles the service.

### Defined types

* [`fail2ban::define`](#fail2ban--define): == Define: fail2ban::define
* [`fail2ban::jail`](#fail2ban--jail): Handles the jails.

### Data types

* [`Fail2ban::Time`](#Fail2ban--Time): Describes time format allowed for bantime and findtime The time entries in fail2ban configuration (like findtime or bantime) can be provided 

### Tasks

* [`banip`](#banip): Ban IPs in a jail
* [`unban`](#unban): Unban IP in all jails and database
* [`unbanip`](#unbanip): Unban IP in a jail

## Classes

### <a name="fail2ban"></a>`fail2ban`

This module installs, configures and manages the Fail2ban service.
Main class, includes all other classes.

#### Parameters

The following parameters are available in the `fail2ban` class:

* [`package_ensure`](#-fail2ban--package_ensure)
* [`package_name`](#-fail2ban--package_name)
* [`package_list`](#-fail2ban--package_list)
* [`config_dir_path`](#-fail2ban--config_dir_path)
* [`config_dir_purge`](#-fail2ban--config_dir_purge)
* [`config_dir_recurse`](#-fail2ban--config_dir_recurse)
* [`config_dir_source`](#-fail2ban--config_dir_source)
* [`config_file_path`](#-fail2ban--config_file_path)
* [`config_file_owner`](#-fail2ban--config_file_owner)
* [`config_file_group`](#-fail2ban--config_file_group)
* [`config_file_mode`](#-fail2ban--config_file_mode)
* [`config_file_source`](#-fail2ban--config_file_source)
* [`config_file_string`](#-fail2ban--config_file_string)
* [`config_file_template`](#-fail2ban--config_file_template)
* [`config_file_notify`](#-fail2ban--config_file_notify)
* [`config_file_require`](#-fail2ban--config_file_require)
* [`config_file_hash`](#-fail2ban--config_file_hash)
* [`config_file_options_hash`](#-fail2ban--config_file_options_hash)
* [`manage_defaults`](#-fail2ban--manage_defaults)
* [`manage_firewalld`](#-fail2ban--manage_firewalld)
* [`service_ensure`](#-fail2ban--service_ensure)
* [`service_name`](#-fail2ban--service_name)
* [`service_enable`](#-fail2ban--service_enable)
* [`action`](#-fail2ban--action)
* [`bantime`](#-fail2ban--bantime)
* [`email`](#-fail2ban--email)
* [`sender`](#-fail2ban--sender)
* [`iptables_chain`](#-fail2ban--iptables_chain)
* [`jails`](#-fail2ban--jails)
* [`maxretry`](#-fail2ban--maxretry)
* [`whitelist`](#-fail2ban--whitelist)
* [`custom_jails`](#-fail2ban--custom_jails)
* [`banaction`](#-fail2ban--banaction)
* [`config_file_before`](#-fail2ban--config_file_before)
* [`config_dir_filter_path`](#-fail2ban--config_dir_filter_path)
* [`default_backend`](#-fail2ban--default_backend)
* [`sendmail_config`](#-fail2ban--sendmail_config)
* [`sendmail_actions`](#-fail2ban--sendmail_actions)

##### <a name="-fail2ban--package_ensure"></a>`package_ensure`

Data type: `Enum['absent', 'latest', 'present', 'purged']`

Determines if the package should be installed.

Default value: `'present'`

##### <a name="-fail2ban--package_name"></a>`package_name`

Data type: `String[1]`

Determines the name of package to manage.

Default value: `'fail2ban'`

##### <a name="-fail2ban--package_list"></a>`package_list`

Data type: `Optional[Array[String]]`

Determines if additional packages should be managed.

Default value: `undef`

##### <a name="-fail2ban--config_dir_path"></a>`config_dir_path`

Data type: `Stdlib::Absolutepath`

Determines if the configuration directory should be managed.

Default value: `'/etc/fail2ban'`

##### <a name="-fail2ban--config_dir_purge"></a>`config_dir_purge`

Data type: `Boolean`

Determines if unmanaged configuration files should be removed.

Default value: `false`

##### <a name="-fail2ban--config_dir_recurse"></a>`config_dir_recurse`

Data type: `Boolean`

Determines if the configuration directory should be recursively managed.

Default value: `true`

##### <a name="-fail2ban--config_dir_source"></a>`config_dir_source`

Data type: `Optional[String]`

Determines the source of a configuration directory.

Default value: `undef`

##### <a name="-fail2ban--config_file_path"></a>`config_file_path`

Data type: `Stdlib::Absolutepath`

Determines if the configuration file should be managed.

Default value: `'/etc/fail2ban/jail.conf'`

##### <a name="-fail2ban--config_file_owner"></a>`config_file_owner`

Data type: `String[1]`

Determines which user should own the configuration file.

Default value: `'root'`

##### <a name="-fail2ban--config_file_group"></a>`config_file_group`

Data type: `String[1]`

Determines which group should own the configuration file.

Default value: `'root'`

##### <a name="-fail2ban--config_file_mode"></a>`config_file_mode`

Data type: `String[1]`

Determines the desired permissions mode of the configuration file.

Default value: `'0644'`

##### <a name="-fail2ban--config_file_source"></a>`config_file_source`

Data type: `Optional[String[1]]`

Determines the source of a configuration file.

Default value: `undef`

##### <a name="-fail2ban--config_file_string"></a>`config_file_string`

Data type: `Optional[String[1]]`

Determines the content of a configuration file.

Default value: `undef`

##### <a name="-fail2ban--config_file_template"></a>`config_file_template`

Data type: `Optional[String[1]]`

Determines the content of a configuration file.

Default value: `undef`

##### <a name="-fail2ban--config_file_notify"></a>`config_file_notify`

Data type: `String[1]`

Determines if the service should be restarted after configuration changes.

Default value: `'Service[fail2ban]'`

##### <a name="-fail2ban--config_file_require"></a>`config_file_require`

Data type: `String[1]`

Determines which package a configuration file depends on.

Default value: `'Package[fail2ban]'`

##### <a name="-fail2ban--config_file_hash"></a>`config_file_hash`

Data type: `Hash[String[1], Any]`

Determines which configuration files should be managed via `fail2ban::define`.

Default value: `{}`

##### <a name="-fail2ban--config_file_options_hash"></a>`config_file_options_hash`

Data type: `Hash`

Determines which parameters should be passed to an ERB template.

Default value: `{}`

##### <a name="-fail2ban--manage_defaults"></a>`manage_defaults`

Data type: `Enum['absent', 'present']`

Determines whether the file `/etc/fail2ban/jail.d/defaults-debian.conf` should be deleted or not.

Default value: `'absent'`

##### <a name="-fail2ban--manage_firewalld"></a>`manage_firewalld`

Data type: `Enum['absent', 'present']`

Determines whether the file `/etc/fail2ban/jail.d/00-firewalld.conf` should be deleted or not.

Default value: `'absent'`

##### <a name="-fail2ban--service_ensure"></a>`service_ensure`

Data type: `Enum['running', 'stopped']`

Determines if the service should be running or not.

Default value: `'running'`

##### <a name="-fail2ban--service_name"></a>`service_name`

Data type: `String[1]`

Determines the name of service to manage.

Default value: `'fail2ban'`

##### <a name="-fail2ban--service_enable"></a>`service_enable`

Data type: `Boolean`

Determines if the service should be enabled at boot.

Default value: `true`

##### <a name="-fail2ban--action"></a>`action`

Data type: `String[1]`

Determines how banned ip addresses should be reported.

Default value: `'action_mb'`

##### <a name="-fail2ban--bantime"></a>`bantime`

Data type: `Fail2ban::Time`

Determines how many time (second or hour or week) ip addresses will be banned.

Default value: `432000`

##### <a name="-fail2ban--email"></a>`email`

Data type: `String[1]`

Determines which email address should be notified about restricted hosts and suspicious logins.

Default value: `"fail2ban@${facts['networking']['domain']}"`

##### <a name="-fail2ban--sender"></a>`sender`

Data type: `String[1]`

Determines which email address should notify about restricted hosts and suspicious logins.

Default value: `"fail2ban@${facts['networking']['fqdn']}"`

##### <a name="-fail2ban--iptables_chain"></a>`iptables_chain`

Data type: `String[1]`

Determines chain where jumps will to be added in iptables-\* actions.

Default value: `'INPUT'`

##### <a name="-fail2ban--jails"></a>`jails`

Data type: `Array[String[1]]`

Determines which services should be protected by Fail2ban.

Default value: `['ssh', 'ssh-ddos']`

##### <a name="-fail2ban--maxretry"></a>`maxretry`

Data type: `Integer[0]`

Determines the number of failed login attempts needed to block a host.

Default value: `3`

##### <a name="-fail2ban--whitelist"></a>`whitelist`

Data type: `Array`

Determines which ip addresses will not be reported

Default value: `['127.0.0.1/8', '192.168.56.0/24']`

##### <a name="-fail2ban--custom_jails"></a>`custom_jails`

Data type: `Hash[String, Hash]`

Determines which custom jails should be included

Default value: `{}`

##### <a name="-fail2ban--banaction"></a>`banaction`

Data type: `String[1]`

Determines which action to perform when performing a global ban (not overridden in a specific jail).

Default value: `'iptables-multiport'`

##### <a name="-fail2ban--config_file_before"></a>`config_file_before`

Data type: `String[1]`



##### <a name="-fail2ban--config_dir_filter_path"></a>`config_dir_filter_path`

Data type: `Stdlib::Absolutepath`



Default value: `'/etc/fail2ban/filter.d'`

##### <a name="-fail2ban--default_backend"></a>`default_backend`

Data type: `Enum['pyinotify', 'gamin', 'polling', 'systemd', 'auto']`



Default value: `'auto'`

##### <a name="-fail2ban--sendmail_config"></a>`sendmail_config`

Data type: `Hash`



Default value: `{}`

##### <a name="-fail2ban--sendmail_actions"></a>`sendmail_actions`

Data type: `Hash`



Default value: `{}`

### <a name="fail2ban--install"></a>`fail2ban::install`

== Class: fail2ban::install

## Defined types

### <a name="fail2ban--define"></a>`fail2ban::define`

== Define: fail2ban::define

#### Parameters

The following parameters are available in the `fail2ban::define` defined type:

* [`config_file_path`](#-fail2ban--define--config_file_path)
* [`config_file_owner`](#-fail2ban--define--config_file_owner)
* [`config_file_group`](#-fail2ban--define--config_file_group)
* [`config_file_mode`](#-fail2ban--define--config_file_mode)
* [`config_file_source`](#-fail2ban--define--config_file_source)
* [`config_file_string`](#-fail2ban--define--config_file_string)
* [`config_file_template`](#-fail2ban--define--config_file_template)
* [`config_file_notify`](#-fail2ban--define--config_file_notify)
* [`config_file_require`](#-fail2ban--define--config_file_require)
* [`config_file_options_hash`](#-fail2ban--define--config_file_options_hash)

##### <a name="-fail2ban--define--config_file_path"></a>`config_file_path`

Data type: `Stdlib::Absolutepath`



Default value: `"${fail2ban::config_dir_path}/${title}"`

##### <a name="-fail2ban--define--config_file_owner"></a>`config_file_owner`

Data type: `String`



Default value: `$fail2ban::config_file_owner`

##### <a name="-fail2ban--define--config_file_group"></a>`config_file_group`

Data type: `String`



Default value: `$fail2ban::config_file_group`

##### <a name="-fail2ban--define--config_file_mode"></a>`config_file_mode`

Data type: `String`



Default value: `$fail2ban::config_file_mode`

##### <a name="-fail2ban--define--config_file_source"></a>`config_file_source`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-fail2ban--define--config_file_string"></a>`config_file_string`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-fail2ban--define--config_file_template"></a>`config_file_template`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-fail2ban--define--config_file_notify"></a>`config_file_notify`

Data type: `String`



Default value: `$fail2ban::config_file_notify`

##### <a name="-fail2ban--define--config_file_require"></a>`config_file_require`

Data type: `String`



Default value: `$fail2ban::config_file_require`

##### <a name="-fail2ban--define--config_file_options_hash"></a>`config_file_options_hash`

Data type: `Hash`



Default value: `$fail2ban::config_file_options_hash`

### <a name="fail2ban--jail"></a>`fail2ban::jail`

Handles the jails.

#### Parameters

The following parameters are available in the `fail2ban::jail` defined type:

* [`filter_includes`](#-fail2ban--jail--filter_includes)
* [`filter_failregex`](#-fail2ban--jail--filter_failregex)
* [`filter_ignoreregex`](#-fail2ban--jail--filter_ignoreregex)
* [`filter_maxlines`](#-fail2ban--jail--filter_maxlines)
* [`filter_datepattern`](#-fail2ban--jail--filter_datepattern)
* [`filter_additional_config`](#-fail2ban--jail--filter_additional_config)
* [`enabled`](#-fail2ban--jail--enabled)
* [`action`](#-fail2ban--jail--action)
* [`filter`](#-fail2ban--jail--filter)
* [`logpath`](#-fail2ban--jail--logpath)
* [`maxretry`](#-fail2ban--jail--maxretry)
* [`findtime`](#-fail2ban--jail--findtime)
* [`bantime`](#-fail2ban--jail--bantime)
* [`port`](#-fail2ban--jail--port)
* [`backend`](#-fail2ban--jail--backend)
* [`journalmatch`](#-fail2ban--jail--journalmatch)
* [`ignoreip`](#-fail2ban--jail--ignoreip)
* [`config_dir_filter_path`](#-fail2ban--jail--config_dir_filter_path)
* [`config_file_owner`](#-fail2ban--jail--config_file_owner)
* [`config_file_group`](#-fail2ban--jail--config_file_group)
* [`config_file_mode`](#-fail2ban--jail--config_file_mode)
* [`config_file_source`](#-fail2ban--jail--config_file_source)
* [`config_file_notify`](#-fail2ban--jail--config_file_notify)
* [`config_file_require`](#-fail2ban--jail--config_file_require)

##### <a name="-fail2ban--jail--filter_includes"></a>`filter_includes`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-fail2ban--jail--filter_failregex"></a>`filter_failregex`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-fail2ban--jail--filter_ignoreregex"></a>`filter_ignoreregex`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-fail2ban--jail--filter_maxlines"></a>`filter_maxlines`

Data type: `Optional[Integer]`



Default value: `undef`

##### <a name="-fail2ban--jail--filter_datepattern"></a>`filter_datepattern`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-fail2ban--jail--filter_additional_config"></a>`filter_additional_config`

Data type: `Any`



Default value: `undef`

##### <a name="-fail2ban--jail--enabled"></a>`enabled`

Data type: `Boolean`



Default value: `true`

##### <a name="-fail2ban--jail--action"></a>`action`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-fail2ban--jail--filter"></a>`filter`

Data type: `String`



Default value: `$title`

##### <a name="-fail2ban--jail--logpath"></a>`logpath`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-fail2ban--jail--maxretry"></a>`maxretry`

Data type: `Integer`



Default value: `$fail2ban::maxretry`

##### <a name="-fail2ban--jail--findtime"></a>`findtime`

Data type: `Optional[Fail2ban::Time]`



Default value: `undef`

##### <a name="-fail2ban--jail--bantime"></a>`bantime`

Data type: `Fail2ban::Time`



Default value: `$fail2ban::bantime`

##### <a name="-fail2ban--jail--port"></a>`port`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-fail2ban--jail--backend"></a>`backend`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-fail2ban--jail--journalmatch"></a>`journalmatch`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-fail2ban--jail--ignoreip"></a>`ignoreip`

Data type: `Array[Stdlib::IP::Address]`



Default value: `[]`

##### <a name="-fail2ban--jail--config_dir_filter_path"></a>`config_dir_filter_path`

Data type: `Stdlib::Absolutepath`



Default value: `$fail2ban::config_dir_filter_path`

##### <a name="-fail2ban--jail--config_file_owner"></a>`config_file_owner`

Data type: `Optional[String]`



Default value: `$fail2ban::config_file_owner`

##### <a name="-fail2ban--jail--config_file_group"></a>`config_file_group`

Data type: `Optional[String]`



Default value: `$fail2ban::config_file_group`

##### <a name="-fail2ban--jail--config_file_mode"></a>`config_file_mode`

Data type: `Optional[String]`



Default value: `$fail2ban::config_file_mode`

##### <a name="-fail2ban--jail--config_file_source"></a>`config_file_source`

Data type: `Optional[String]`



Default value: `$fail2ban::config_file_source`

##### <a name="-fail2ban--jail--config_file_notify"></a>`config_file_notify`

Data type: `Optional[String]`



Default value: `$fail2ban::config_file_notify`

##### <a name="-fail2ban--jail--config_file_require"></a>`config_file_require`

Data type: `Optional[String]`



Default value: `$fail2ban::config_file_require`

## Data types

### <a name="Fail2ban--Time"></a>`Fail2ban::Time`

Describes time format allowed for bantime and findtime
The time entries in fail2ban configuration (like findtime or bantime)
can be provided as integer in seconds or as string using special abbreviation
format (e. g. 600 is the same as 10m).

Abbreviation tokens:

  years?, yea?, yy?
  months?, mon?
  weeks?, wee?, ww?
  days?, da, dd?
  hours?, hou?, hh?
  minutes?, min?, mm?
  seconds?, sec?, ss?

  The question mark (?) means the optional character, so day as well as days can be used.

You can combine multiple tokens in format (separated with space resp. without separator), e. g.: 1y 6mo or 1d12h30m.
Note that tokens m as well as mm means minutes, for month use abbreviation mo or mon.

The time format can be tested using fail2ban-client:

       fail2ban-client --str2sec 1d12h

Alias of `Variant[Integer[0], Pattern['^\d.*$']]`

## Tasks

### <a name="banip"></a>`banip`

Ban IPs in a jail

**Supports noop?** false

#### Parameters

##### `jail`

Data type: `String[1]`

The jail to operate on

##### `ips`

Data type: `Array[Stdlib::IP::Address]`

IP addresses to ban

### <a name="unban"></a>`unban`

Unban IP in all jails and database

**Supports noop?** false

#### Parameters

##### `ips`

Data type: `Array[Stdlib::IP::Address]`

IP addresses to unban

### <a name="unbanip"></a>`unbanip`

Unban IP in a jail

**Supports noop?** false

#### Parameters

##### `jail`

Data type: `String[1]`

The jail to operate on

##### `ips`

Data type: `Array[Stdlib::IP::Address]`

IP addresses to unban

